@@ -2,11 +2,11 @@ use 5.008;
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::Lib;
-# git description: v0.014-1-ga76cf9b
+# git description: v0.015-1-ga474073
 
 our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Basic functions to access a BenchmarkAnything store
-$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.015';
+$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.016';
 use Scalar::Util 'reftype';
 
 
@@ -625,6 +625,35 @@ sub listkeys
 }
 
 
+sub stats
+{
+        my ($self) = @_;
+
+        my $backend = $self->{config}{benchmarkanything}{backend};
+        if ($backend eq 'local')
+        {
+                return $self->{backend}->get_stats;
+        }
+        elsif ($backend eq 'http')
+        {
+                my $ua  = $self->_get_user_agent;
+                my $url = $self->_get_base_url."/api/v1/stats";
+
+                my $res = $ua->get($url)->res;
+                die "benchmarkanything: ".$res->error->{message}." ($url)\n" if $res->error;
+
+                my $result = $res->json;
+
+                # output
+                return $result;
+        }
+        else
+        {
+                die "benchmarkanything: no backend '$backend', available backends are: 'http', 'local'.\n";
+        }
+}
+
+
 sub gc
 {
         my ($self) = @_;
@@ -906,6 +935,11 @@ Returns an array ref with all additional key names that are used for
 metrics. Optionally allows to restrict the search by a SQL LIKE search
 pattern, allowing C<%> as wildcard.
 
+=head2 stats
+
+Returns a hash with info about the storage, like how many data points,
+how many metrics, how many additional keys, are stored.
+
 =head2 gc()
 
 Run garbage collector. This cleans up potential garbage that might
